/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                Java Language GNSS Compass SDK, Version 6.0                 */
/*                    Copyright 2022, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2022 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* Satellites Detailed */
public class ANPacket31
{
	public static final int SATELLITE_SYSTEM_UNKNOWN 	= 0;
	public static final int SATELLITE_SYSTEM_GPS 		= 1;
	public static final int SATELLITE_SYSTEM_GLONASS 	= 2;
	public static final int SATELLITE_SYSTEM_BEIDOU 	= 3;
	public static final int SATELLITE_SYSTEM_GALILEO 	= 4;
	public static final int SATELLITE_SYSTEM_SBAS 		= 5;
	public static final int SATELLITE_SYSTEM_QZSS 		= 6;
	public static final int SATELLITE_SYSTEM_STARFIRE 	= 7;
	public static final int SATELLITE_SYSTEM_OMNISTAR 	= 8;

	public static final int SATELLITE_FREQUENCY_L1_CA 	= 0;
	public static final int SATELLITE_FREQUENCY_L1_C 	= 1;
	public static final int SATELLITE_FREQUENCY_L1_P 	= 2;
	public static final int SATELLITE_FREQUENCY_L1_M 	= 3;
	public static final int SATELLITE_FREQUENCY_L2_C 	= 4;
	public static final int SATELLITE_FREQUENCY_L2_P 	= 5;
	public static final int SATELLITE_FREQUENCY_L2_M 	= 6;
	public static final int SATELLITE_FREQUENCY_L5 		= 7;

	public int gpsSatellites;
	public int glonassSatellites;
	public int sbasSatellites;
	public int qzssSatellites;
	public int galileoSatellites;
	public int beidouSatellites;
	public Satellite[] satellites;

	public ANPacket31(ANPacket packet)
	{
		gpsSatellites = 0;
		glonassSatellites = 0;
		sbasSatellites = 0;
		qzssSatellites = 0;
		galileoSatellites = 0;
		beidouSatellites = 0;
		satellites = new Satellite[packet.length/7];
		for(int i=0; i < satellites.length; i++)
		{
			satellites[i] = new Satellite();
			satellites[i].satelliteSystem = packet.data[7*i] & 0xFF;
			satellites[i].number = packet.data[7*i+1] & 0xFF;
			satellites[i].frequency = packet.data[7*i+2] & 0xFF;
			satellites[i].elevation = packet.data[7*i+3] & 0xFF;
			satellites[i].azimuth = TypeConversion.bytesToUInt16(packet.data, 7*i+4);
			satellites[i].snr = packet.data[7*i+6] & 0xFF;
			if(satellites[i].satelliteSystem == SATELLITE_SYSTEM_GPS) gpsSatellites++;
			else if(satellites[i].satelliteSystem == SATELLITE_SYSTEM_GLONASS) glonassSatellites++;
			else if(satellites[i].satelliteSystem == SATELLITE_SYSTEM_SBAS) sbasSatellites++;
			else if(satellites[i].satelliteSystem == SATELLITE_SYSTEM_QZSS) qzssSatellites++;
			else if(satellites[i].satelliteSystem == SATELLITE_SYSTEM_GALILEO) galileoSatellites++;
			else if(satellites[i].satelliteSystem == SATELLITE_SYSTEM_BEIDOU) beidouSatellites++;
		}
	}

	public class Satellite
	{
		public int satelliteSystem;
		public int number;
		public int frequency;
		public int elevation;
		public int azimuth;
		public int snr;

		public String satelliteSystemName()
		{
			switch(satelliteSystem)
			{
				case SATELLITE_SYSTEM_GPS:
					return "GPS";
				case SATELLITE_SYSTEM_GLONASS:
					return "GLONASS";
				case SATELLITE_SYSTEM_BEIDOU:
					return "BEIDOU";
				case SATELLITE_SYSTEM_GALILEO:
					return "GALILEO";
				case SATELLITE_SYSTEM_SBAS:
					return "SBAS";
				case SATELLITE_SYSTEM_QZSS:
					return "QZSS";
				case SATELLITE_SYSTEM_STARFIRE:
					return "Starfire";
				case SATELLITE_SYSTEM_OMNISTAR:
					return "Omnistar";
				default:
					return "Unknown";
			}
		}
	}
}
